@@ -693,15 +693,15 @@ CacheDatabase::refreshInboxModel (InboxModel *modelInbox,
 {
     GVI_Entry_Type Type = modelInbox->string_to_type (strType);
     QString strQ = "SELECT "
-                   GV_IN_ID ","
-                   GV_IN_TYPE ","
-                   GV_IN_ATTIME ","
-                   GV_IN_DISPNUM ","
-                   GV_IN_PHONE ","
-                   GV_IN_FLAGS ","
-                   GV_IN_SMSTEXT ","
-                   GV_IN_NOTE " "
-                   "FROM " GV_INBOX_TABLE;
+                            GV_IN_ID      ","
+                            GV_IN_TYPE    ","
+                            GV_IN_ATTIME  ","
+                            GV_IN_DISPNUM ","
+                            GV_IN_PHONE   ","
+                            GV_IN_FLAGS   ","
+                            GV_IN_SMSTEXT ","
+                            GV_IN_NOTE    " "
+                   "FROM "  GV_INBOX_TABLE;
     if (GVIE_Unknown != Type) {
         strQ += QString (" WHERE " GV_IN_TYPE "=%1 ").arg (Type);
     }
@@ -849,6 +849,54 @@ CacheDatabase::insertInboxEntry (const GVInboxEntry &hEvent)
     return (rv);
 }//CacheDatabase::insertInboxEntry
 
+bool
+CacheDatabase::markAsRead (const QString &msgId)
+{
+    QString scrubId = msgId;
+    scrubId.replace ("'", "''");
+
+    QSqlQuery query(dbMain);
+    query.setForwardOnly (true);
+
+    bool rv = false;
+    do { // Begin cleanup block (not a loop)
+        rv = query.exec (QString("SELECT " GV_IN_FLAGS " FROM " GV_INBOX_TABLE
+                                 " WHERE " GV_IN_ID "='%1'").arg (scrubId));
+        if (!rv || !query.next ()) {
+            rv = false;
+            qWarning ("Failed to get the inbox entry to mark as read");
+            break;
+        }
+
+        quint32 flags = query.value (0).toInt (&rv);
+        if (!rv) {
+            qWarning ("Failed to convert flags result into integer");
+            break;
+        }
+
+        if (flags & (1 << 0)) {
+            qDebug("Entry was already read. no need to re-mark.");
+            rv = false;
+            break;
+        }
+
+        flags |= (1 << 0);
+
+        rv = query.exec (QString("UPDATE " GV_INBOX_TABLE " "
+                                 "SET " GV_IN_FLAGS "=%1 "
+                                 "WHERE " GV_IN_ID "='%2'")
+                         .arg(flags).arg (scrubId));
+        if (!rv) {
+            qWarning ("Failed to update inbox table with a flag marked read");
+            break;
+        }
+
+        rv = true;
+    } while (0); // End cleanup block (not a loop)
+
+    return (rv);
+}//CacheDatabase::markAsRead
+
 QStringList
 CacheDatabase::getTextsByDate(QDateTime dtStart, QDateTime dtEnd)
 {
